git.delta.rocks / unique-network / refs/commits / b85120ee5b8d

difftreelog

fix rename method to collectionSponsor

Trubnikov Sergey2022-09-19parent: #280815c.patch.diff
in: master

21 files changed

modifiedpallets/common/src/erc.rsdiffbeforeafterboth
--- a/pallets/common/src/erc.rs
+++ b/pallets/common/src/erc.rs
@@ -194,7 +194,7 @@
 	/// Get current sponsor.
 	///
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
-	fn get_collection_sponsor(&self) -> Result<(address, uint256)> {
+	fn collection_sponsor(&self) -> Result<(address, uint256)> {
 		let sponsor = match self.collection.sponsorship.sponsor() {
 			Some(sponsor) => sponsor,
 			None => return Ok(Default::default()),
modifiedpallets/evm-contract-helpers/src/stubs/ContractHelpers.rawdiffbeforeafterboth

binary blob — no preview

modifiedpallets/evm-contract-helpers/src/stubs/ContractHelpers.soldiffbeforeafterboth
before · pallets/evm-contract-helpers/src/stubs/ContractHelpers.sol
1// SPDX-License-Identifier: OTHER2// This code is automatically generated34pragma solidity >=0.8.0 <0.9.0;56/// @dev common stubs holder7contract Dummy {8	uint8 dummy;9	string stub_error = "this contract is implemented in native";10}1112contract ERC165 is Dummy {13	function supportsInterface(bytes4 interfaceID)14		external15		view16		returns (bool)17	{18		require(false, stub_error);19		interfaceID;20		return true;21	}22}2324/// @dev inlined interface25contract ContractHelpersEvents {26	event ContractSponsorSet(address indexed contractAddress, address sponsor);27	event ContractSponsorshipConfirmed(28		address indexed contractAddress,29		address sponsor30	);31	event ContractSponsorRemoved(address indexed contractAddress);32}3334/// @title Magic contract, which allows users to reconfigure other contracts35/// @dev the ERC-165 identifier for this interface is 0x172cb4fb36contract ContractHelpers is Dummy, ERC165, ContractHelpersEvents {37	/// Get user, which deployed specified contract38	/// @dev May return zero address in case if contract is deployed39	///  using uniquenetwork evm-migration pallet, or using other terms not40	///  intended by pallet-evm41	/// @dev Returns zero address if contract does not exists42	/// @param contractAddress Contract to get owner of43	/// @return address Owner of contract44	/// @dev EVM selector for this function is: 0x5152b14c,45	///  or in textual repr: contractOwner(address)46	function contractOwner(address contractAddress)47		public48		view49		returns (address)50	{51		require(false, stub_error);52		contractAddress;53		dummy;54		return 0x0000000000000000000000000000000000000000;55	}5657	/// Set sponsor.58	/// @param contractAddress Contract for which a sponsor is being established.59	/// @param sponsor User address who set as pending sponsor.60	/// @dev EVM selector for this function is: 0xf01fba93,61	///  or in textual repr: setSponsor(address,address)62	function setSponsor(address contractAddress, address sponsor) public {63		require(false, stub_error);64		contractAddress;65		sponsor;66		dummy = 0;67	}6869	/// Set contract as self sponsored.70	///71	/// @param contractAddress Contract for which a self sponsoring is being enabled.72	/// @dev EVM selector for this function is: 0x89f7d9ae,73	///  or in textual repr: selfSponsoredEnable(address)74	function selfSponsoredEnable(address contractAddress) public {75		require(false, stub_error);76		contractAddress;77		dummy = 0;78	}7980	/// Remove sponsor.81	///82	/// @param contractAddress Contract for which a sponsorship is being removed.83	/// @dev EVM selector for this function is: 0xef784250,84	///  or in textual repr: removeSponsor(address)85	function removeSponsor(address contractAddress) public {86		require(false, stub_error);87		contractAddress;88		dummy = 0;89	}9091	/// Confirm sponsorship.92	///93	/// @dev Caller must be same that set via [`setSponsor`].94	///95	/// @param contractAddress Сontract for which need to confirm sponsorship.96	/// @dev EVM selector for this function is: 0xabc00001,97	///  or in textual repr: confirmSponsorship(address)98	function confirmSponsorship(address contractAddress) public {99		require(false, stub_error);100		contractAddress;101		dummy = 0;102	}103104	/// Get current sponsor.105	///106	/// @param contractAddress The contract for which a sponsor is requested.107	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.108	/// @dev EVM selector for this function is: 0x743fc745,109	///  or in textual repr: getSponsor(address)110	function getSponsor(address contractAddress)111		public112		view113		returns (Tuple0 memory)114	{115		require(false, stub_error);116		contractAddress;117		dummy;118		return Tuple0(0x0000000000000000000000000000000000000000, 0);119	}120121	/// Check tat contract has confirmed sponsor.122	///123	/// @param contractAddress The contract for which the presence of a confirmed sponsor is checked.124	/// @return **true** if contract has confirmed sponsor.125	/// @dev EVM selector for this function is: 0x97418603,126	///  or in textual repr: hasSponsor(address)127	function hasSponsor(address contractAddress) public view returns (bool) {128		require(false, stub_error);129		contractAddress;130		dummy;131		return false;132	}133134	/// Check tat contract has pending sponsor.135	///136	/// @param contractAddress The contract for which the presence of a pending sponsor is checked.137	/// @return **true** if contract has pending sponsor.138	/// @dev EVM selector for this function is: 0x39b9b242,139	///  or in textual repr: hasPendingSponsor(address)140	function hasPendingSponsor(address contractAddress)141		public142		view143		returns (bool)144	{145		require(false, stub_error);146		contractAddress;147		dummy;148		return false;149	}150151	/// @dev EVM selector for this function is: 0x6027dc61,152	///  or in textual repr: sponsoringEnabled(address)153	function sponsoringEnabled(address contractAddress)154		public155		view156		returns (bool)157	{158		require(false, stub_error);159		contractAddress;160		dummy;161		return false;162	}163164	/// @dev EVM selector for this function is: 0xfde8a560,165	///  or in textual repr: setSponsoringMode(address,uint8)166	function setSponsoringMode(address contractAddress, uint8 mode) public {167		require(false, stub_error);168		contractAddress;169		mode;170		dummy = 0;171	}172173	/// Get current contract sponsoring rate limit174	/// @param contractAddress Contract to get sponsoring rate limit of175	/// @return uint32 Amount of blocks between two sponsored transactions176	/// @dev EVM selector for this function is: 0x610cfabd,177	///  or in textual repr: getSponsoringRateLimit(address)178	function getSponsoringRateLimit(address contractAddress)179		public180		view181		returns (uint32)182	{183		require(false, stub_error);184		contractAddress;185		dummy;186		return 0;187	}188189	/// Set contract sponsoring rate limit190	/// @dev Sponsoring rate limit - is a minimum amount of blocks that should191	///  pass between two sponsored transactions192	/// @param contractAddress Contract to change sponsoring rate limit of193	/// @param rateLimit Target rate limit194	/// @dev Only contract owner can change this setting195	/// @dev EVM selector for this function is: 0x77b6c908,196	///  or in textual repr: setSponsoringRateLimit(address,uint32)197	function setSponsoringRateLimit(address contractAddress, uint32 rateLimit)198		public199	{200		require(false, stub_error);201		contractAddress;202		rateLimit;203		dummy = 0;204	}205206	/// Set contract sponsoring fee limit207	/// @dev Sponsoring fee limit - is maximum fee that could be spent by208	///  single transaction209	/// @param contractAddress Contract to change sponsoring fee limit of210	/// @param feeLimit Fee limit211	/// @dev Only contract owner can change this setting212	/// @dev EVM selector for this function is: 0x03aed665,213	///  or in textual repr: setSponsoringFeeLimit(address,uint256)214	function setSponsoringFeeLimit(address contractAddress, uint256 feeLimit)215		public216	{217		require(false, stub_error);218		contractAddress;219		feeLimit;220		dummy = 0;221	}222223	/// Get current contract sponsoring fee limit224	/// @param contractAddress Contract to get sponsoring fee limit of225	/// @return uint256 Maximum amount of fee that could be spent by single226	///  transaction227	/// @dev EVM selector for this function is: 0xc3fdc9ee,228	///  or in textual repr: getSponsoringFeeLimit(address)229	function getSponsoringFeeLimit(address contractAddress)230		public231		view232		returns (uint256)233	{234		require(false, stub_error);235		contractAddress;236		dummy;237		return 0;238	}239240	/// Is specified user present in contract allow list241	/// @dev Contract owner always implicitly included242	/// @param contractAddress Contract to check allowlist of243	/// @param user User to check244	/// @return bool Is specified users exists in contract allowlist245	/// @dev EVM selector for this function is: 0x5c658165,246	///  or in textual repr: allowed(address,address)247	function allowed(address contractAddress, address user)248		public249		view250		returns (bool)251	{252		require(false, stub_error);253		contractAddress;254		user;255		dummy;256		return false;257	}258259	/// Toggle user presence in contract allowlist260	/// @param contractAddress Contract to change allowlist of261	/// @param user Which user presence should be toggled262	/// @param isAllowed `true` if user should be allowed to be sponsored263	///  or call this contract, `false` otherwise264	/// @dev Only contract owner can change this setting265	/// @dev EVM selector for this function is: 0x4706cc1c,266	///  or in textual repr: toggleAllowed(address,address,bool)267	function toggleAllowed(268		address contractAddress,269		address user,270		bool isAllowed271	) public {272		require(false, stub_error);273		contractAddress;274		user;275		isAllowed;276		dummy = 0;277	}278279	/// Is this contract has allowlist access enabled280	/// @dev Allowlist always can have users, and it is used for two purposes:281	///  in case of allowlist sponsoring mode, users will be sponsored if they exist in allowlist282	///  in case of allowlist access enabled, only users from allowlist may call this contract283	/// @param contractAddress Contract to get allowlist access of284	/// @return bool Is specified contract has allowlist access enabled285	/// @dev EVM selector for this function is: 0xc772ef6c,286	///  or in textual repr: allowlistEnabled(address)287	function allowlistEnabled(address contractAddress)288		public289		view290		returns (bool)291	{292		require(false, stub_error);293		contractAddress;294		dummy;295		return false;296	}297298	/// Toggle contract allowlist access299	/// @param contractAddress Contract to change allowlist access of300	/// @param enabled Should allowlist access to be enabled?301	/// @dev EVM selector for this function is: 0x36de20f5,302	///  or in textual repr: toggleAllowlist(address,bool)303	function toggleAllowlist(address contractAddress, bool enabled) public {304		require(false, stub_error);305		contractAddress;306		enabled;307		dummy = 0;308	}309}310311/// @dev anonymous struct312struct Tuple0 {313	address field_0;314	uint256 field_1;315}
after · pallets/evm-contract-helpers/src/stubs/ContractHelpers.sol
1// SPDX-License-Identifier: OTHER2// This code is automatically generated34pragma solidity >=0.8.0 <0.9.0;56/// @dev common stubs holder7contract Dummy {8	uint8 dummy;9	string stub_error = "this contract is implemented in native";10}1112contract ERC165 is Dummy {13	function supportsInterface(bytes4 interfaceID) external view returns (bool) {14		require(false, stub_error);15		interfaceID;16		return true;17	}18}1920/// @dev inlined interface21contract ContractHelpersEvents {22	event ContractSponsorSet(address indexed contractAddress, address sponsor);23	event ContractSponsorshipConfirmed(address indexed contractAddress, address sponsor);24	event ContractSponsorRemoved(address indexed contractAddress);25}2627/// @title Magic contract, which allows users to reconfigure other contracts28/// @dev the ERC-165 identifier for this interface is 0x172cb4fb29contract ContractHelpers is Dummy, ERC165, ContractHelpersEvents {30	/// Get user, which deployed specified contract31	/// @dev May return zero address in case if contract is deployed32	///  using uniquenetwork evm-migration pallet, or using other terms not33	///  intended by pallet-evm34	/// @dev Returns zero address if contract does not exists35	/// @param contractAddress Contract to get owner of36	/// @return address Owner of contract37	/// @dev EVM selector for this function is: 0x5152b14c,38	///  or in textual repr: contractOwner(address)39	function contractOwner(address contractAddress) public view returns (address) {40		require(false, stub_error);41		contractAddress;42		dummy;43		return 0x0000000000000000000000000000000000000000;44	}4546	/// Set sponsor.47	/// @param contractAddress Contract for which a sponsor is being established.48	/// @param sponsor User address who set as pending sponsor.49	/// @dev EVM selector for this function is: 0xf01fba93,50	///  or in textual repr: setSponsor(address,address)51	function setSponsor(address contractAddress, address sponsor) public {52		require(false, stub_error);53		contractAddress;54		sponsor;55		dummy = 0;56	}5758	/// Set contract as self sponsored.59	///60	/// @param contractAddress Contract for which a self sponsoring is being enabled.61	/// @dev EVM selector for this function is: 0x89f7d9ae,62	///  or in textual repr: selfSponsoredEnable(address)63	function selfSponsoredEnable(address contractAddress) public {64		require(false, stub_error);65		contractAddress;66		dummy = 0;67	}6869	/// Remove sponsor.70	///71	/// @param contractAddress Contract for which a sponsorship is being removed.72	/// @dev EVM selector for this function is: 0xef784250,73	///  or in textual repr: removeSponsor(address)74	function removeSponsor(address contractAddress) public {75		require(false, stub_error);76		contractAddress;77		dummy = 0;78	}7980	/// Confirm sponsorship.81	///82	/// @dev Caller must be same that set via [`setSponsor`].83	///84	/// @param contractAddress Сontract for which need to confirm sponsorship.85	/// @dev EVM selector for this function is: 0xabc00001,86	///  or in textual repr: confirmSponsorship(address)87	function confirmSponsorship(address contractAddress) public {88		require(false, stub_error);89		contractAddress;90		dummy = 0;91	}9293	/// Get current sponsor.94	///95	/// @param contractAddress The contract for which a sponsor is requested.96	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.97	/// @dev EVM selector for this function is: 0x743fc745,98	///  or in textual repr: getSponsor(address)99	function getSponsor(address contractAddress) public view returns (Tuple0 memory) {100		require(false, stub_error);101		contractAddress;102		dummy;103		return Tuple0(0x0000000000000000000000000000000000000000, 0);104	}105106	/// Check tat contract has confirmed sponsor.107	///108	/// @param contractAddress The contract for which the presence of a confirmed sponsor is checked.109	/// @return **true** if contract has confirmed sponsor.110	/// @dev EVM selector for this function is: 0x97418603,111	///  or in textual repr: hasSponsor(address)112	function hasSponsor(address contractAddress) public view returns (bool) {113		require(false, stub_error);114		contractAddress;115		dummy;116		return false;117	}118119	/// Check tat contract has pending sponsor.120	///121	/// @param contractAddress The contract for which the presence of a pending sponsor is checked.122	/// @return **true** if contract has pending sponsor.123	/// @dev EVM selector for this function is: 0x39b9b242,124	///  or in textual repr: hasPendingSponsor(address)125	function hasPendingSponsor(address contractAddress) public view returns (bool) {126		require(false, stub_error);127		contractAddress;128		dummy;129		return false;130	}131132	/// @dev EVM selector for this function is: 0x6027dc61,133	///  or in textual repr: sponsoringEnabled(address)134	function sponsoringEnabled(address contractAddress) public view returns (bool) {135		require(false, stub_error);136		contractAddress;137		dummy;138		return false;139	}140141	/// @dev EVM selector for this function is: 0xfde8a560,142	///  or in textual repr: setSponsoringMode(address,uint8)143	function setSponsoringMode(address contractAddress, uint8 mode) public {144		require(false, stub_error);145		contractAddress;146		mode;147		dummy = 0;148	}149150	/// Get current contract sponsoring rate limit151	/// @param contractAddress Contract to get sponsoring rate limit of152	/// @return uint32 Amount of blocks between two sponsored transactions153	/// @dev EVM selector for this function is: 0x610cfabd,154	///  or in textual repr: getSponsoringRateLimit(address)155	function getSponsoringRateLimit(address contractAddress) public view returns (uint32) {156		require(false, stub_error);157		contractAddress;158		dummy;159		return 0;160	}161162	/// Set contract sponsoring rate limit163	/// @dev Sponsoring rate limit - is a minimum amount of blocks that should164	///  pass between two sponsored transactions165	/// @param contractAddress Contract to change sponsoring rate limit of166	/// @param rateLimit Target rate limit167	/// @dev Only contract owner can change this setting168	/// @dev EVM selector for this function is: 0x77b6c908,169	///  or in textual repr: setSponsoringRateLimit(address,uint32)170	function setSponsoringRateLimit(address contractAddress, uint32 rateLimit) public {171		require(false, stub_error);172		contractAddress;173		rateLimit;174		dummy = 0;175	}176177	/// Set contract sponsoring fee limit178	/// @dev Sponsoring fee limit - is maximum fee that could be spent by179	///  single transaction180	/// @param contractAddress Contract to change sponsoring fee limit of181	/// @param feeLimit Fee limit182	/// @dev Only contract owner can change this setting183	/// @dev EVM selector for this function is: 0x03aed665,184	///  or in textual repr: setSponsoringFeeLimit(address,uint256)185	function setSponsoringFeeLimit(address contractAddress, uint256 feeLimit) public {186		require(false, stub_error);187		contractAddress;188		feeLimit;189		dummy = 0;190	}191192	/// Get current contract sponsoring fee limit193	/// @param contractAddress Contract to get sponsoring fee limit of194	/// @return uint256 Maximum amount of fee that could be spent by single195	///  transaction196	/// @dev EVM selector for this function is: 0xc3fdc9ee,197	///  or in textual repr: getSponsoringFeeLimit(address)198	function getSponsoringFeeLimit(address contractAddress) public view returns (uint256) {199		require(false, stub_error);200		contractAddress;201		dummy;202		return 0;203	}204205	/// Is specified user present in contract allow list206	/// @dev Contract owner always implicitly included207	/// @param contractAddress Contract to check allowlist of208	/// @param user User to check209	/// @return bool Is specified users exists in contract allowlist210	/// @dev EVM selector for this function is: 0x5c658165,211	///  or in textual repr: allowed(address,address)212	function allowed(address contractAddress, address user) public view returns (bool) {213		require(false, stub_error);214		contractAddress;215		user;216		dummy;217		return false;218	}219220	/// Toggle user presence in contract allowlist221	/// @param contractAddress Contract to change allowlist of222	/// @param user Which user presence should be toggled223	/// @param isAllowed `true` if user should be allowed to be sponsored224	///  or call this contract, `false` otherwise225	/// @dev Only contract owner can change this setting226	/// @dev EVM selector for this function is: 0x4706cc1c,227	///  or in textual repr: toggleAllowed(address,address,bool)228	function toggleAllowed(229		address contractAddress,230		address user,231		bool isAllowed232	) public {233		require(false, stub_error);234		contractAddress;235		user;236		isAllowed;237		dummy = 0;238	}239240	/// Is this contract has allowlist access enabled241	/// @dev Allowlist always can have users, and it is used for two purposes:242	///  in case of allowlist sponsoring mode, users will be sponsored if they exist in allowlist243	///  in case of allowlist access enabled, only users from allowlist may call this contract244	/// @param contractAddress Contract to get allowlist access of245	/// @return bool Is specified contract has allowlist access enabled246	/// @dev EVM selector for this function is: 0xc772ef6c,247	///  or in textual repr: allowlistEnabled(address)248	function allowlistEnabled(address contractAddress) public view returns (bool) {249		require(false, stub_error);250		contractAddress;251		dummy;252		return false;253	}254255	/// Toggle contract allowlist access256	/// @param contractAddress Contract to change allowlist access of257	/// @param enabled Should allowlist access to be enabled?258	/// @dev EVM selector for this function is: 0x36de20f5,259	///  or in textual repr: toggleAllowlist(address,bool)260	function toggleAllowlist(address contractAddress, bool enabled) public {261		require(false, stub_error);262		contractAddress;263		enabled;264		dummy = 0;265	}266}267268/// @dev anonymous struct269struct Tuple0 {270	address field_0;271	uint256 field_1;272}
modifiedpallets/fungible/src/stubs/UniqueFungible.rawdiffbeforeafterboth

binary blob — no preview

modifiedpallets/fungible/src/stubs/UniqueFungible.soldiffbeforeafterboth
--- a/pallets/refungible/src/stubs/UniqueRefungibleToken.sol
+++ b/pallets/refungible/src/stubs/UniqueRefungibleToken.sol
@@ -10,11 +10,7 @@
 }
 
 contract ERC165 is Dummy {
-	function supportsInterface(bytes4 interfaceID)
-		external
-		view
-		returns (bool)
-	{
+	function supportsInterface(bytes4 interfaceID) external view returns (bool) {
 		require(false, stub_error);
 		interfaceID;
 		return true;
@@ -72,11 +68,7 @@
 /// @dev inlined interface
 contract ERC20Events {
 	event Transfer(address indexed from, address indexed to, uint256 value);
-	event Approval(
-		address indexed owner,
-		address indexed spender,
-		uint256 value
-	);
+	event Approval(address indexed owner, address indexed spender, uint256 value);
 }
 
 /// @title Standard ERC20 token
@@ -188,11 +180,7 @@
 	/// @return A uint256 specifying the amount of tokens still available for the spender.
 	/// @dev EVM selector for this function is: 0xdd62ed3e,
 	///  or in textual repr: allowance(address,address)
-	function allowance(address owner, address spender)
-		public
-		view
-		returns (uint256)
-	{
+	function allowance(address owner, address spender) public view returns (uint256) {
 		require(false, stub_error);
 		owner;
 		spender;
@@ -201,10 +189,4 @@
 	}
 }
 
-contract UniqueRefungibleToken is
-	Dummy,
-	ERC165,
-	ERC20,
-	ERC20UniqueExtensions,
-	ERC1633
-{}
+contract UniqueRefungibleToken is Dummy, ERC165, ERC20, ERC20UniqueExtensions, ERC1633 {}
modifiedpallets/unique/src/eth/stubs/CollectionHelpers.rawdiffbeforeafterboth

binary blob — no preview

modifiedtests/src/eth/api/ContractHelpers.soldiffbeforeafterboth
--- a/tests/src/eth/api/ContractHelpers.sol
+++ b/tests/src/eth/api/ContractHelpers.sol
@@ -15,10 +15,7 @@
 /// @dev inlined interface
 interface ContractHelpersEvents {
 	event ContractSponsorSet(address indexed contractAddress, address sponsor);
-	event ContractSponsorshipConfirmed(
-		address indexed contractAddress,
-		address sponsor
-	);
+	event ContractSponsorshipConfirmed(address indexed contractAddress, address sponsor);
 	event ContractSponsorRemoved(address indexed contractAddress);
 }
 
@@ -34,10 +31,7 @@
 	/// @return address Owner of contract
 	/// @dev EVM selector for this function is: 0x5152b14c,
 	///  or in textual repr: contractOwner(address)
-	function contractOwner(address contractAddress)
-		external
-		view
-		returns (address);
+	function contractOwner(address contractAddress) external view returns (address);
 
 	/// Set sponsor.
 	/// @param contractAddress Contract for which a sponsor is being established.
@@ -75,10 +69,7 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x743fc745,
 	///  or in textual repr: getSponsor(address)
-	function getSponsor(address contractAddress)
-		external
-		view
-		returns (Tuple0 memory);
+	function getSponsor(address contractAddress) external view returns (Tuple0 memory);
 
 	/// Check tat contract has confirmed sponsor.
 	///
@@ -94,17 +85,11 @@
 	/// @return **true** if contract has pending sponsor.
 	/// @dev EVM selector for this function is: 0x39b9b242,
 	///  or in textual repr: hasPendingSponsor(address)
-	function hasPendingSponsor(address contractAddress)
-		external
-		view
-		returns (bool);
+	function hasPendingSponsor(address contractAddress) external view returns (bool);
 
 	/// @dev EVM selector for this function is: 0x6027dc61,
 	///  or in textual repr: sponsoringEnabled(address)
-	function sponsoringEnabled(address contractAddress)
-		external
-		view
-		returns (bool);
+	function sponsoringEnabled(address contractAddress) external view returns (bool);
 
 	/// @dev EVM selector for this function is: 0xfde8a560,
 	///  or in textual repr: setSponsoringMode(address,uint8)
@@ -115,10 +100,7 @@
 	/// @return uint32 Amount of blocks between two sponsored transactions
 	/// @dev EVM selector for this function is: 0x610cfabd,
 	///  or in textual repr: getSponsoringRateLimit(address)
-	function getSponsoringRateLimit(address contractAddress)
-		external
-		view
-		returns (uint32);
+	function getSponsoringRateLimit(address contractAddress) external view returns (uint32);
 
 	/// Set contract sponsoring rate limit
 	/// @dev Sponsoring rate limit - is a minimum amount of blocks that should
@@ -128,8 +110,7 @@
 	/// @dev Only contract owner can change this setting
 	/// @dev EVM selector for this function is: 0x77b6c908,
 	///  or in textual repr: setSponsoringRateLimit(address,uint32)
-	function setSponsoringRateLimit(address contractAddress, uint32 rateLimit)
-		external;
+	function setSponsoringRateLimit(address contractAddress, uint32 rateLimit) external;
 
 	/// Set contract sponsoring fee limit
 	/// @dev Sponsoring fee limit - is maximum fee that could be spent by
@@ -139,8 +120,7 @@
 	/// @dev Only contract owner can change this setting
 	/// @dev EVM selector for this function is: 0x03aed665,
 	///  or in textual repr: setSponsoringFeeLimit(address,uint256)
-	function setSponsoringFeeLimit(address contractAddress, uint256 feeLimit)
-		external;
+	function setSponsoringFeeLimit(address contractAddress, uint256 feeLimit) external;
 
 	/// Get current contract sponsoring fee limit
 	/// @param contractAddress Contract to get sponsoring fee limit of
@@ -148,10 +128,7 @@
 	///  transaction
 	/// @dev EVM selector for this function is: 0xc3fdc9ee,
 	///  or in textual repr: getSponsoringFeeLimit(address)
-	function getSponsoringFeeLimit(address contractAddress)
-		external
-		view
-		returns (uint256);
+	function getSponsoringFeeLimit(address contractAddress) external view returns (uint256);
 
 	/// Is specified user present in contract allow list
 	/// @dev Contract owner always implicitly included
@@ -160,10 +137,7 @@
 	/// @return bool Is specified users exists in contract allowlist
 	/// @dev EVM selector for this function is: 0x5c658165,
 	///  or in textual repr: allowed(address,address)
-	function allowed(address contractAddress, address user)
-		external
-		view
-		returns (bool);
+	function allowed(address contractAddress, address user) external view returns (bool);
 
 	/// Toggle user presence in contract allowlist
 	/// @param contractAddress Contract to change allowlist of
@@ -187,10 +161,7 @@
 	/// @return bool Is specified contract has allowlist access enabled
 	/// @dev EVM selector for this function is: 0xc772ef6c,
 	///  or in textual repr: allowlistEnabled(address)
-	function allowlistEnabled(address contractAddress)
-		external
-		view
-		returns (bool);
+	function allowlistEnabled(address contractAddress) external view returns (bool);
 
 	/// Toggle contract allowlist access
 	/// @param contractAddress Contract to change allowlist access of
modifiedtests/src/eth/api/UniqueFungible.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueRefungibleToken.sol
+++ b/tests/src/eth/api/UniqueRefungibleToken.sol
@@ -44,11 +44,7 @@
 /// @dev inlined interface
 interface ERC20Events {
 	event Transfer(address indexed from, address indexed to, uint256 value);
-	event Approval(
-		address indexed owner,
-		address indexed spender,
-		uint256 value
-	);
+	event Approval(address indexed owner, address indexed spender, uint256 value);
 }
 
 /// @title Standard ERC20 token
@@ -120,16 +116,7 @@
 	/// @return A uint256 specifying the amount of tokens still available for the spender.
 	/// @dev EVM selector for this function is: 0xdd62ed3e,
 	///  or in textual repr: allowance(address,address)
-	function allowance(address owner, address spender)
-		external
-		view
-		returns (uint256);
+	function allowance(address owner, address spender) external view returns (uint256);
 }
 
-interface UniqueRefungibleToken is
-	Dummy,
-	ERC165,
-	ERC20,
-	ERC20UniqueExtensions,
-	ERC1633
-{}
+interface UniqueRefungibleToken is Dummy, ERC165, ERC20, ERC20UniqueExtensions, ERC1633 {}
modifiedtests/src/eth/collectionSponsoring.test.tsdiffbeforeafterboth
--- a/tests/src/eth/collectionSponsoring.test.ts
+++ b/tests/src/eth/collectionSponsoring.test.ts
@@ -56,7 +56,7 @@
     await submitTransactionAsync(sponsor, confirmTx);
     expect(await collectionEvm.methods.hasCollectionPendingSponsor().call({from: owner})).to.be.false;
     
-    const sponsorTuple = await collectionEvm.methods.getCollectionSponsor().call({from: owner});
+    const sponsorTuple = await collectionEvm.methods.collectionSponsor().call({from: owner});
     expect(bigIntToSub(api, BigInt(sponsorTuple[1]))).to.be.eq(sponsor.address);
   });
 
@@ -77,7 +77,7 @@
     
     await collectionEvm.methods.removeCollectionSponsor().send({from: owner});
     
-    const sponsorTuple = await collectionEvm.methods.getCollectionSponsor().call({from: owner});
+    const sponsorTuple = await collectionEvm.methods.collectionSponsor().call({from: owner});
     expect(sponsorTuple.field_0).to.be.eq('0x0000000000000000000000000000000000000000');
   });
 
modifiedtests/src/eth/fungibleAbi.jsondiffbeforeafterboth
--- a/tests/src/eth/fungibleAbi.json
+++ b/tests/src/eth/fungibleAbi.json
@@ -159,6 +159,23 @@
   },
   {
     "inputs": [],
+    "name": "collectionSponsor",
+    "outputs": [
+      {
+        "components": [
+          { "internalType": "address", "name": "field_0", "type": "address" },
+          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+        ],
+        "internalType": "struct Tuple6",
+        "name": "",
+        "type": "tuple"
+      }
+    ],
+    "stateMutability": "view",
+    "type": "function"
+  },
+  {
+    "inputs": [],
     "name": "confirmCollectionSponsorship",
     "outputs": [],
     "stateMutability": "nonpayable",
@@ -183,23 +200,6 @@
     "name": "deleteCollectionProperty",
     "outputs": [],
     "stateMutability": "nonpayable",
-    "type": "function"
-  },
-  {
-    "inputs": [],
-    "name": "getCollectionSponsor",
-    "outputs": [
-      {
-        "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
-        ],
-        "internalType": "struct Tuple6",
-        "name": "",
-        "type": "tuple"
-      }
-    ],
-    "stateMutability": "view",
     "type": "function"
   },
   {
@@ -453,7 +453,7 @@
     "inputs": [],
     "name": "uniqueCollectionType",
     "outputs": [{ "internalType": "string", "name": "", "type": "string" }],
-    "stateMutability": "nonpayable",
+    "stateMutability": "view",
     "type": "function"
   }
 ]
modifiedtests/src/eth/nonFungibleAbi.jsondiffbeforeafterboth
--- a/tests/src/eth/nonFungibleAbi.json
+++ b/tests/src/eth/nonFungibleAbi.json
@@ -189,6 +189,23 @@
   },
   {
     "inputs": [],
+    "name": "collectionSponsor",
+    "outputs": [
+      {
+        "components": [
+          { "internalType": "address", "name": "field_0", "type": "address" },
+          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+        ],
+        "internalType": "struct Tuple17",
+        "name": "",
+        "type": "tuple"
+      }
+    ],
+    "stateMutability": "view",
+    "type": "function"
+  },
+  {
+    "inputs": [],
     "name": "confirmCollectionSponsorship",
     "outputs": [],
     "stateMutability": "nonpayable",
@@ -231,23 +248,6 @@
     ],
     "name": "getApproved",
     "outputs": [{ "internalType": "address", "name": "", "type": "address" }],
-    "stateMutability": "view",
-    "type": "function"
-  },
-  {
-    "inputs": [],
-    "name": "getCollectionSponsor",
-    "outputs": [
-      {
-        "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
-        ],
-        "internalType": "struct Tuple17",
-        "name": "",
-        "type": "tuple"
-      }
-    ],
     "stateMutability": "view",
     "type": "function"
   },
@@ -651,7 +651,7 @@
     "inputs": [],
     "name": "uniqueCollectionType",
     "outputs": [{ "internalType": "string", "name": "", "type": "string" }],
-    "stateMutability": "nonpayable",
+    "stateMutability": "view",
     "type": "function"
   }
 ]
modifiedtests/src/eth/reFungibleAbi.jsondiffbeforeafterboth
--- a/tests/src/eth/reFungibleAbi.json
+++ b/tests/src/eth/reFungibleAbi.json
@@ -189,6 +189,23 @@
   },
   {
     "inputs": [],
+    "name": "collectionSponsor",
+    "outputs": [
+      {
+        "components": [
+          { "internalType": "address", "name": "field_0", "type": "address" },
+          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
+        ],
+        "internalType": "struct Tuple17",
+        "name": "",
+        "type": "tuple"
+      }
+    ],
+    "stateMutability": "view",
+    "type": "function"
+  },
+  {
+    "inputs": [],
     "name": "confirmCollectionSponsorship",
     "outputs": [],
     "stateMutability": "nonpayable",
@@ -231,23 +248,6 @@
     ],
     "name": "getApproved",
     "outputs": [{ "internalType": "address", "name": "", "type": "address" }],
-    "stateMutability": "view",
-    "type": "function"
-  },
-  {
-    "inputs": [],
-    "name": "getCollectionSponsor",
-    "outputs": [
-      {
-        "components": [
-          { "internalType": "address", "name": "field_0", "type": "address" },
-          { "internalType": "uint256", "name": "field_1", "type": "uint256" }
-        ],
-        "internalType": "struct Tuple17",
-        "name": "",
-        "type": "tuple"
-      }
-    ],
     "stateMutability": "view",
     "type": "function"
   },
@@ -660,7 +660,7 @@
     "inputs": [],
     "name": "uniqueCollectionType",
     "outputs": [{ "internalType": "string", "name": "", "type": "string" }],
-    "stateMutability": "nonpayable",
+    "stateMutability": "view",
     "type": "function"
   }
 ]
--- a/pallets/fungible/src/stubs/UniqueFungible.sol
+++ b/pallets/fungible/src/stubs/UniqueFungible.sol
@@ -10,11 +10,7 @@
 }
 
 contract ERC165 is Dummy {
-	function supportsInterface(bytes4 interfaceID)
-		external
-		view
-		returns (bool)
-	{
+	function supportsInterface(bytes4 interfaceID) external view returns (bool) {
 		require(false, stub_error);
 		interfaceID;
 		return true;
@@ -22,7 +18,7 @@
 }
 
 /// @title A contract that allows you to work with collections.
-/// @dev the ERC-165 identifier for this interface is 0x9f70d4e0
+/// @dev the ERC-165 identifier for this interface is 0x47dbc105
 contract Collection is Dummy, ERC165 {
 	/// Set collection property.
 	///
@@ -30,9 +26,7 @@
 	/// @param value Propery value.
 	/// @dev EVM selector for this function is: 0x2f073f66,
 	///  or in textual repr: setCollectionProperty(string,bytes)
-	function setCollectionProperty(string memory key, bytes memory value)
-		public
-	{
+	function setCollectionProperty(string memory key, bytes memory value) public {
 		require(false, stub_error);
 		key;
 		value;
@@ -58,11 +52,7 @@
 	/// @return bytes The property corresponding to the key.
 	/// @dev EVM selector for this function is: 0xcf24fd6d,
 	///  or in textual repr: collectionProperty(string)
-	function collectionProperty(string memory key)
-		public
-		view
-		returns (bytes memory)
-	{
+	function collectionProperty(string memory key) public view returns (bytes memory) {
 		require(false, stub_error);
 		key;
 		dummy;
@@ -95,6 +85,7 @@
 		dummy = 0;
 	}
 
+	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
 	///  or in textual repr: hasCollectionPendingSponsor()
 	function hasCollectionPendingSponsor() public view returns (bool) {
@@ -124,9 +115,9 @@
 	/// Get current sponsor.
 	///
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
-	/// @dev EVM selector for this function is: 0xb66bbc14,
-	///  or in textual repr: getCollectionSponsor()
-	function getCollectionSponsor() public view returns (Tuple6 memory) {
+	/// @dev EVM selector for this function is: 0x6ec0a9f1,
+	///  or in textual repr: collectionSponsor()
+	function collectionSponsor() public view returns (Tuple6 memory) {
 		require(false, stub_error);
 		dummy;
 		return Tuple6(0x0000000000000000000000000000000000000000, 0);
@@ -234,9 +225,7 @@
 	/// @param collections Addresses of collections that will be available for nesting.
 	/// @dev EVM selector for this function is: 0x64872396,
 	///  or in textual repr: setCollectionNesting(bool,address[])
-	function setCollectionNesting(bool enable, address[] memory collections)
-		public
-	{
+	function setCollectionNesting(bool enable, address[] memory collections) public {
 		require(false, stub_error);
 		enable;
 		collections;
@@ -353,9 +342,9 @@
 	/// @return `Fungible` or `NFT` or `ReFungible`
 	/// @dev EVM selector for this function is: 0xd34b55b8,
 	///  or in textual repr: uniqueCollectionType()
-	function uniqueCollectionType() public returns (string memory) {
+	function uniqueCollectionType() public view returns (string memory) {
 		require(false, stub_error);
-		dummy = 0;
+		dummy;
 		return "";
 	}
 
@@ -450,11 +439,7 @@
 /// @dev inlined interface
 contract ERC20Events {
 	event Transfer(address indexed from, address indexed to, uint256 value);
-	event Approval(
-		address indexed owner,
-		address indexed spender,
-		uint256 value
-	);
+	event Approval(address indexed owner, address indexed spender, uint256 value);
 }
 
 /// @dev the ERC-165 identifier for this interface is 0x942e8b22
@@ -537,11 +522,7 @@
 
 	/// @dev EVM selector for this function is: 0xdd62ed3e,
 	///  or in textual repr: allowance(address,address)
-	function allowance(address owner, address spender)
-		public
-		view
-		returns (uint256)
-	{
+	function allowance(address owner, address spender) public view returns (uint256) {
 		require(false, stub_error);
 		owner;
 		spender;
@@ -550,11 +531,4 @@
 	}
 }
 
-contract UniqueFungible is
-	Dummy,
-	ERC165,
-	ERC20,
-	ERC20Mintable,
-	ERC20UniqueExtensions,
-	Collection
-{}
+contract UniqueFungible is Dummy, ERC165, ERC20, ERC20Mintable, ERC20UniqueExtensions, Collection {}
modifiedpallets/nonfungible/src/stubs/UniqueNFT.rawdiffbeforeafterboth

binary blob — no preview

modifiedpallets/nonfungible/src/stubs/UniqueNFT.soldiffbeforeafterboth
--- a/pallets/nonfungible/src/stubs/UniqueNFT.sol
+++ b/pallets/nonfungible/src/stubs/UniqueNFT.sol
@@ -10,11 +10,7 @@
 }
 
 contract ERC165 is Dummy {
-	function supportsInterface(bytes4 interfaceID)
-		external
-		view
-		returns (bool)
-	{
+	function supportsInterface(bytes4 interfaceID) external view returns (bool) {
 		require(false, stub_error);
 		interfaceID;
 		return true;
@@ -85,11 +81,7 @@
 	/// @return Property value bytes
 	/// @dev EVM selector for this function is: 0x7228c327,
 	///  or in textual repr: property(uint256,string)
-	function property(uint256 tokenId, string memory key)
-		public
-		view
-		returns (bytes memory)
-	{
+	function property(uint256 tokenId, string memory key) public view returns (bytes memory) {
 		require(false, stub_error);
 		tokenId;
 		key;
@@ -99,7 +91,7 @@
 }
 
 /// @title A contract that allows you to work with collections.
-/// @dev the ERC-165 identifier for this interface is 0x9f70d4e0
+/// @dev the ERC-165 identifier for this interface is 0x47dbc105
 contract Collection is Dummy, ERC165 {
 	/// Set collection property.
 	///
@@ -107,9 +99,7 @@
 	/// @param value Propery value.
 	/// @dev EVM selector for this function is: 0x2f073f66,
 	///  or in textual repr: setCollectionProperty(string,bytes)
-	function setCollectionProperty(string memory key, bytes memory value)
-		public
-	{
+	function setCollectionProperty(string memory key, bytes memory value) public {
 		require(false, stub_error);
 		key;
 		value;
@@ -135,11 +125,7 @@
 	/// @return bytes The property corresponding to the key.
 	/// @dev EVM selector for this function is: 0xcf24fd6d,
 	///  or in textual repr: collectionProperty(string)
-	function collectionProperty(string memory key)
-		public
-		view
-		returns (bytes memory)
-	{
+	function collectionProperty(string memory key) public view returns (bytes memory) {
 		require(false, stub_error);
 		key;
 		dummy;
@@ -172,6 +158,7 @@
 		dummy = 0;
 	}
 
+	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
 	///  or in textual repr: hasCollectionPendingSponsor()
 	function hasCollectionPendingSponsor() public view returns (bool) {
@@ -201,9 +188,9 @@
 	/// Get current sponsor.
 	///
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
-	/// @dev EVM selector for this function is: 0xb66bbc14,
-	///  or in textual repr: getCollectionSponsor()
-	function getCollectionSponsor() public view returns (Tuple17 memory) {
+	/// @dev EVM selector for this function is: 0x6ec0a9f1,
+	///  or in textual repr: collectionSponsor()
+	function collectionSponsor() public view returns (Tuple17 memory) {
 		require(false, stub_error);
 		dummy;
 		return Tuple17(0x0000000000000000000000000000000000000000, 0);
@@ -311,9 +298,7 @@
 	/// @param collections Addresses of collections that will be available for nesting.
 	/// @dev EVM selector for this function is: 0x64872396,
 	///  or in textual repr: setCollectionNesting(bool,address[])
-	function setCollectionNesting(bool enable, address[] memory collections)
-		public
-	{
+	function setCollectionNesting(bool enable, address[] memory collections) public {
 		require(false, stub_error);
 		enable;
 		collections;
@@ -430,9 +415,9 @@
 	/// @return `Fungible` or `NFT` or `ReFungible`
 	/// @dev EVM selector for this function is: 0xd34b55b8,
 	///  or in textual repr: uniqueCollectionType()
-	function uniqueCollectionType() public returns (string memory) {
+	function uniqueCollectionType() public view returns (string memory) {
 		require(false, stub_error);
-		dummy = 0;
+		dummy;
 		return "";
 	}
 
@@ -605,10 +590,7 @@
 	/// @param tokenIds IDs of the minted NFTs
 	/// @dev EVM selector for this function is: 0x44a9945e,
 	///  or in textual repr: mintBulk(address,uint256[])
-	function mintBulk(address to, uint256[] memory tokenIds)
-		public
-		returns (bool)
-	{
+	function mintBulk(address to, uint256[] memory tokenIds) public returns (bool) {
 		require(false, stub_error);
 		to;
 		tokenIds;
@@ -623,10 +605,7 @@
 	/// @param tokens array of pairs of token ID and token URI for minted tokens
 	/// @dev EVM selector for this function is: 0x36543006,
 	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
-	function mintBulkWithTokenURI(address to, Tuple8[] memory tokens)
-		public
-		returns (bool)
-	{
+	function mintBulkWithTokenURI(address to, Tuple8[] memory tokens) public returns (bool) {
 		require(false, stub_error);
 		to;
 		tokens;
@@ -661,11 +640,7 @@
 	/// @dev Not implemented
 	/// @dev EVM selector for this function is: 0x2f745c59,
 	///  or in textual repr: tokenOfOwnerByIndex(address,uint256)
-	function tokenOfOwnerByIndex(address owner, uint256 index)
-		public
-		view
-		returns (uint256)
-	{
+	function tokenOfOwnerByIndex(address owner, uint256 index) public view returns (uint256) {
 		require(false, stub_error);
 		owner;
 		index;
@@ -728,21 +703,9 @@
 
 /// @dev inlined interface
 contract ERC721Events {
-	event Transfer(
-		address indexed from,
-		address indexed to,
-		uint256 indexed tokenId
-	);
-	event Approval(
-		address indexed owner,
-		address indexed approved,
-		uint256 indexed tokenId
-	);
-	event ApprovalForAll(
-		address indexed owner,
-		address indexed operator,
-		bool approved
-	);
+	event Transfer(address indexed from, address indexed to, uint256 indexed tokenId);
+	event Approval(address indexed owner, address indexed approved, uint256 indexed tokenId);
+	event ApprovalForAll(address indexed owner, address indexed operator, bool approved);
 }
 
 /// @title ERC-721 Non-Fungible Token Standard
@@ -870,11 +833,7 @@
 	/// @dev Not implemented
 	/// @dev EVM selector for this function is: 0xe985e9c5,
 	///  or in textual repr: isApprovedForAll(address,address)
-	function isApprovedForAll(address owner, address operator)
-		public
-		view
-		returns (address)
-	{
+	function isApprovedForAll(address owner, address operator) public view returns (address) {
 		require(false, stub_error);
 		owner;
 		operator;
modifiedpallets/refungible/src/stubs/UniqueRefungible.rawdiffbeforeafterboth

binary blob — no preview

modifiedpallets/refungible/src/stubs/UniqueRefungible.soldiffbeforeafterboth
--- a/pallets/refungible/src/stubs/UniqueRefungible.sol
+++ b/pallets/refungible/src/stubs/UniqueRefungible.sol
@@ -10,11 +10,7 @@
 }
 
 contract ERC165 is Dummy {
-	function supportsInterface(bytes4 interfaceID)
-		external
-		view
-		returns (bool)
-	{
+	function supportsInterface(bytes4 interfaceID) external view returns (bool) {
 		require(false, stub_error);
 		interfaceID;
 		return true;
@@ -85,11 +81,7 @@
 	/// @return Property value bytes
 	/// @dev EVM selector for this function is: 0x7228c327,
 	///  or in textual repr: property(uint256,string)
-	function property(uint256 tokenId, string memory key)
-		public
-		view
-		returns (bytes memory)
-	{
+	function property(uint256 tokenId, string memory key) public view returns (bytes memory) {
 		require(false, stub_error);
 		tokenId;
 		key;
@@ -99,7 +91,7 @@
 }
 
 /// @title A contract that allows you to work with collections.
-/// @dev the ERC-165 identifier for this interface is 0x9f70d4e0
+/// @dev the ERC-165 identifier for this interface is 0x47dbc105
 contract Collection is Dummy, ERC165 {
 	/// Set collection property.
 	///
@@ -107,9 +99,7 @@
 	/// @param value Propery value.
 	/// @dev EVM selector for this function is: 0x2f073f66,
 	///  or in textual repr: setCollectionProperty(string,bytes)
-	function setCollectionProperty(string memory key, bytes memory value)
-		public
-	{
+	function setCollectionProperty(string memory key, bytes memory value) public {
 		require(false, stub_error);
 		key;
 		value;
@@ -135,11 +125,7 @@
 	/// @return bytes The property corresponding to the key.
 	/// @dev EVM selector for this function is: 0xcf24fd6d,
 	///  or in textual repr: collectionProperty(string)
-	function collectionProperty(string memory key)
-		public
-		view
-		returns (bytes memory)
-	{
+	function collectionProperty(string memory key) public view returns (bytes memory) {
 		require(false, stub_error);
 		key;
 		dummy;
@@ -172,6 +158,7 @@
 		dummy = 0;
 	}
 
+	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
 	///  or in textual repr: hasCollectionPendingSponsor()
 	function hasCollectionPendingSponsor() public view returns (bool) {
@@ -201,9 +188,9 @@
 	/// Get current sponsor.
 	///
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
-	/// @dev EVM selector for this function is: 0xb66bbc14,
-	///  or in textual repr: getCollectionSponsor()
-	function getCollectionSponsor() public view returns (Tuple17 memory) {
+	/// @dev EVM selector for this function is: 0x6ec0a9f1,
+	///  or in textual repr: collectionSponsor()
+	function collectionSponsor() public view returns (Tuple17 memory) {
 		require(false, stub_error);
 		dummy;
 		return Tuple17(0x0000000000000000000000000000000000000000, 0);
@@ -311,9 +298,7 @@
 	/// @param collections Addresses of collections that will be available for nesting.
 	/// @dev EVM selector for this function is: 0x64872396,
 	///  or in textual repr: setCollectionNesting(bool,address[])
-	function setCollectionNesting(bool enable, address[] memory collections)
-		public
-	{
+	function setCollectionNesting(bool enable, address[] memory collections) public {
 		require(false, stub_error);
 		enable;
 		collections;
@@ -430,9 +415,9 @@
 	/// @return `Fungible` or `NFT` or `ReFungible`
 	/// @dev EVM selector for this function is: 0xd34b55b8,
 	///  or in textual repr: uniqueCollectionType()
-	function uniqueCollectionType() public returns (string memory) {
+	function uniqueCollectionType() public view returns (string memory) {
 		require(false, stub_error);
-		dummy = 0;
+		dummy;
 		return "";
 	}
 
@@ -607,10 +592,7 @@
 	/// @param tokenIds IDs of the minted RFTs
 	/// @dev EVM selector for this function is: 0x44a9945e,
 	///  or in textual repr: mintBulk(address,uint256[])
-	function mintBulk(address to, uint256[] memory tokenIds)
-		public
-		returns (bool)
-	{
+	function mintBulk(address to, uint256[] memory tokenIds) public returns (bool) {
 		require(false, stub_error);
 		to;
 		tokenIds;
@@ -625,10 +607,7 @@
 	/// @param tokens array of pairs of token ID and token URI for minted tokens
 	/// @dev EVM selector for this function is: 0x36543006,
 	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
-	function mintBulkWithTokenURI(address to, Tuple8[] memory tokens)
-		public
-		returns (bool)
-	{
+	function mintBulkWithTokenURI(address to, Tuple8[] memory tokens) public returns (bool) {
 		require(false, stub_error);
 		to;
 		tokens;
@@ -675,11 +654,7 @@
 	/// Not implemented
 	/// @dev EVM selector for this function is: 0x2f745c59,
 	///  or in textual repr: tokenOfOwnerByIndex(address,uint256)
-	function tokenOfOwnerByIndex(address owner, uint256 index)
-		public
-		view
-		returns (uint256)
-	{
+	function tokenOfOwnerByIndex(address owner, uint256 index) public view returns (uint256) {
 		require(false, stub_error);
 		owner;
 		index;
@@ -740,21 +715,9 @@
 
 /// @dev inlined interface
 contract ERC721Events {
-	event Transfer(
-		address indexed from,
-		address indexed to,
-		uint256 indexed tokenId
-	);
-	event Approval(
-		address indexed owner,
-		address indexed approved,
-		uint256 indexed tokenId
-	);
-	event ApprovalForAll(
-		address indexed owner,
-		address indexed operator,
-		bool approved
-	);
+	event Transfer(address indexed from, address indexed to, uint256 indexed tokenId);
+	event Approval(address indexed owner, address indexed approved, uint256 indexed tokenId);
+	event ApprovalForAll(address indexed owner, address indexed operator, bool approved);
 }
 
 /// @title ERC-721 Non-Fungible Token Standard
@@ -880,11 +843,7 @@
 	/// @dev Not implemented
 	/// @dev EVM selector for this function is: 0xe985e9c5,
 	///  or in textual repr: isApprovedForAll(address,address)
-	function isApprovedForAll(address owner, address operator)
-		public
-		view
-		returns (address)
-	{
+	function isApprovedForAll(address owner, address operator) public view returns (address) {
 		require(false, stub_error);
 		owner;
 		operator;
modifiedpallets/refungible/src/stubs/UniqueRefungibleToken.rawdiffbeforeafterboth

binary blob — no preview

modifiedpallets/refungible/src/stubs/UniqueRefungibleToken.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueFungible.sol
+++ b/tests/src/eth/api/UniqueFungible.sol
@@ -13,7 +13,7 @@
 }
 
 /// @title A contract that allows you to work with collections.
-/// @dev the ERC-165 identifier for this interface is 0x9f70d4e0
+/// @dev the ERC-165 identifier for this interface is 0x47dbc105
 interface Collection is Dummy, ERC165 {
 	/// Set collection property.
 	///
@@ -21,8 +21,7 @@
 	/// @param value Propery value.
 	/// @dev EVM selector for this function is: 0x2f073f66,
 	///  or in textual repr: setCollectionProperty(string,bytes)
-	function setCollectionProperty(string memory key, bytes memory value)
-		external;
+	function setCollectionProperty(string memory key, bytes memory value) external;
 
 	/// Delete collection property.
 	///
@@ -39,10 +38,7 @@
 	/// @return bytes The property corresponding to the key.
 	/// @dev EVM selector for this function is: 0xcf24fd6d,
 	///  or in textual repr: collectionProperty(string)
-	function collectionProperty(string memory key)
-		external
-		view
-		returns (bytes memory);
+	function collectionProperty(string memory key) external view returns (bytes memory);
 
 	/// Set the sponsor of the collection.
 	///
@@ -62,6 +58,7 @@
 	///  or in textual repr: setCollectionSponsorSubstrate(uint256)
 	function setCollectionSponsorSubstrate(uint256 sponsor) external;
 
+	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
 	///  or in textual repr: hasCollectionPendingSponsor()
 	function hasCollectionPendingSponsor() external view returns (bool);
@@ -81,9 +78,9 @@
 	/// Get current sponsor.
 	///
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
-	/// @dev EVM selector for this function is: 0xb66bbc14,
-	///  or in textual repr: getCollectionSponsor()
-	function getCollectionSponsor() external view returns (Tuple6 memory);
+	/// @dev EVM selector for this function is: 0x6ec0a9f1,
+	///  or in textual repr: collectionSponsor()
+	function collectionSponsor() external view returns (Tuple6 memory);
 
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
@@ -153,8 +150,7 @@
 	/// @param collections Addresses of collections that will be available for nesting.
 	/// @dev EVM selector for this function is: 0x64872396,
 	///  or in textual repr: setCollectionNesting(bool,address[])
-	function setCollectionNesting(bool enable, address[] memory collections)
-		external;
+	function setCollectionNesting(bool enable, address[] memory collections) external;
 
 	/// Set the collection access method.
 	/// @param mode Access mode
@@ -227,7 +223,7 @@
 	/// @return `Fungible` or `NFT` or `ReFungible`
 	/// @dev EVM selector for this function is: 0xd34b55b8,
 	///  or in textual repr: uniqueCollectionType()
-	function uniqueCollectionType() external returns (string memory);
+	function uniqueCollectionType() external view returns (string memory);
 
 	/// Get collection owner.
 	///
@@ -291,11 +287,7 @@
 /// @dev inlined interface
 interface ERC20Events {
 	event Transfer(address indexed from, address indexed to, uint256 value);
-	event Approval(
-		address indexed owner,
-		address indexed spender,
-		uint256 value
-	);
+	event Approval(address indexed owner, address indexed spender, uint256 value);
 }
 
 /// @dev the ERC-165 identifier for this interface is 0x942e8b22
@@ -338,17 +330,7 @@
 
 	/// @dev EVM selector for this function is: 0xdd62ed3e,
 	///  or in textual repr: allowance(address,address)
-	function allowance(address owner, address spender)
-		external
-		view
-		returns (uint256);
+	function allowance(address owner, address spender) external view returns (uint256);
 }
 
-interface UniqueFungible is
-	Dummy,
-	ERC165,
-	ERC20,
-	ERC20Mintable,
-	ERC20UniqueExtensions,
-	Collection
-{}
+interface UniqueFungible is Dummy, ERC165, ERC20, ERC20Mintable, ERC20UniqueExtensions, Collection {}
modifiedtests/src/eth/api/UniqueNFT.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueNFT.sol
+++ b/tests/src/eth/api/UniqueNFT.sol
@@ -58,14 +58,11 @@
 	/// @return Property value bytes
 	/// @dev EVM selector for this function is: 0x7228c327,
 	///  or in textual repr: property(uint256,string)
-	function property(uint256 tokenId, string memory key)
-		external
-		view
-		returns (bytes memory);
+	function property(uint256 tokenId, string memory key) external view returns (bytes memory);
 }
 
 /// @title A contract that allows you to work with collections.
-/// @dev the ERC-165 identifier for this interface is 0x9f70d4e0
+/// @dev the ERC-165 identifier for this interface is 0x47dbc105
 interface Collection is Dummy, ERC165 {
 	/// Set collection property.
 	///
@@ -73,8 +70,7 @@
 	/// @param value Propery value.
 	/// @dev EVM selector for this function is: 0x2f073f66,
 	///  or in textual repr: setCollectionProperty(string,bytes)
-	function setCollectionProperty(string memory key, bytes memory value)
-		external;
+	function setCollectionProperty(string memory key, bytes memory value) external;
 
 	/// Delete collection property.
 	///
@@ -91,10 +87,7 @@
 	/// @return bytes The property corresponding to the key.
 	/// @dev EVM selector for this function is: 0xcf24fd6d,
 	///  or in textual repr: collectionProperty(string)
-	function collectionProperty(string memory key)
-		external
-		view
-		returns (bytes memory);
+	function collectionProperty(string memory key) external view returns (bytes memory);
 
 	/// Set the sponsor of the collection.
 	///
@@ -114,6 +107,7 @@
 	///  or in textual repr: setCollectionSponsorSubstrate(uint256)
 	function setCollectionSponsorSubstrate(uint256 sponsor) external;
 
+	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
 	///  or in textual repr: hasCollectionPendingSponsor()
 	function hasCollectionPendingSponsor() external view returns (bool);
@@ -133,9 +127,9 @@
 	/// Get current sponsor.
 	///
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
-	/// @dev EVM selector for this function is: 0xb66bbc14,
-	///  or in textual repr: getCollectionSponsor()
-	function getCollectionSponsor() external view returns (Tuple17 memory);
+	/// @dev EVM selector for this function is: 0x6ec0a9f1,
+	///  or in textual repr: collectionSponsor()
+	function collectionSponsor() external view returns (Tuple17 memory);
 
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
@@ -205,8 +199,7 @@
 	/// @param collections Addresses of collections that will be available for nesting.
 	/// @dev EVM selector for this function is: 0x64872396,
 	///  or in textual repr: setCollectionNesting(bool,address[])
-	function setCollectionNesting(bool enable, address[] memory collections)
-		external;
+	function setCollectionNesting(bool enable, address[] memory collections) external;
 
 	/// Set the collection access method.
 	/// @param mode Access mode
@@ -279,7 +272,7 @@
 	/// @return `Fungible` or `NFT` or `ReFungible`
 	/// @dev EVM selector for this function is: 0xd34b55b8,
 	///  or in textual repr: uniqueCollectionType()
-	function uniqueCollectionType() external returns (string memory);
+	function uniqueCollectionType() external view returns (string memory);
 
 	/// Get collection owner.
 	///
@@ -399,9 +392,7 @@
 	/// @param tokenIds IDs of the minted NFTs
 	/// @dev EVM selector for this function is: 0x44a9945e,
 	///  or in textual repr: mintBulk(address,uint256[])
-	function mintBulk(address to, uint256[] memory tokenIds)
-		external
-		returns (bool);
+	function mintBulk(address to, uint256[] memory tokenIds) external returns (bool);
 
 	/// @notice Function to mint multiple tokens with the given tokenUris.
 	/// @dev `tokenIds` is array of pairs of token ID and token URI. Token IDs should be consecutive
@@ -410,9 +401,7 @@
 	/// @param tokens array of pairs of token ID and token URI for minted tokens
 	/// @dev EVM selector for this function is: 0x36543006,
 	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
-	function mintBulkWithTokenURI(address to, Tuple8[] memory tokens)
-		external
-		returns (bool);
+	function mintBulkWithTokenURI(address to, Tuple8[] memory tokens) external returns (bool);
 }
 
 /// @dev anonymous struct
@@ -436,10 +425,7 @@
 	/// @dev Not implemented
 	/// @dev EVM selector for this function is: 0x2f745c59,
 	///  or in textual repr: tokenOfOwnerByIndex(address,uint256)
-	function tokenOfOwnerByIndex(address owner, uint256 index)
-		external
-		view
-		returns (uint256);
+	function tokenOfOwnerByIndex(address owner, uint256 index) external view returns (uint256);
 
 	/// @notice Count NFTs tracked by this contract
 	/// @return A count of valid NFTs tracked by this contract, where each one of
@@ -479,21 +465,9 @@
 
 /// @dev inlined interface
 interface ERC721Events {
-	event Transfer(
-		address indexed from,
-		address indexed to,
-		uint256 indexed tokenId
-	);
-	event Approval(
-		address indexed owner,
-		address indexed approved,
-		uint256 indexed tokenId
-	);
-	event ApprovalForAll(
-		address indexed owner,
-		address indexed operator,
-		bool approved
-	);
+	event Transfer(address indexed from, address indexed to, uint256 indexed tokenId);
+	event Approval(address indexed owner, address indexed approved, uint256 indexed tokenId);
+	event ApprovalForAll(address indexed owner, address indexed operator, bool approved);
 }
 
 /// @title ERC-721 Non-Fungible Token Standard
@@ -577,10 +551,7 @@
 	/// @dev Not implemented
 	/// @dev EVM selector for this function is: 0xe985e9c5,
 	///  or in textual repr: isApprovedForAll(address,address)
-	function isApprovedForAll(address owner, address operator)
-		external
-		view
-		returns (address);
+	function isApprovedForAll(address owner, address operator) external view returns (address);
 }
 
 interface UniqueNFT is
modifiedtests/src/eth/api/UniqueRefungible.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueRefungible.sol
+++ b/tests/src/eth/api/UniqueRefungible.sol
@@ -58,14 +58,11 @@
 	/// @return Property value bytes
 	/// @dev EVM selector for this function is: 0x7228c327,
 	///  or in textual repr: property(uint256,string)
-	function property(uint256 tokenId, string memory key)
-		external
-		view
-		returns (bytes memory);
+	function property(uint256 tokenId, string memory key) external view returns (bytes memory);
 }
 
 /// @title A contract that allows you to work with collections.
-/// @dev the ERC-165 identifier for this interface is 0x9f70d4e0
+/// @dev the ERC-165 identifier for this interface is 0x47dbc105
 interface Collection is Dummy, ERC165 {
 	/// Set collection property.
 	///
@@ -73,8 +70,7 @@
 	/// @param value Propery value.
 	/// @dev EVM selector for this function is: 0x2f073f66,
 	///  or in textual repr: setCollectionProperty(string,bytes)
-	function setCollectionProperty(string memory key, bytes memory value)
-		external;
+	function setCollectionProperty(string memory key, bytes memory value) external;
 
 	/// Delete collection property.
 	///
@@ -91,10 +87,7 @@
 	/// @return bytes The property corresponding to the key.
 	/// @dev EVM selector for this function is: 0xcf24fd6d,
 	///  or in textual repr: collectionProperty(string)
-	function collectionProperty(string memory key)
-		external
-		view
-		returns (bytes memory);
+	function collectionProperty(string memory key) external view returns (bytes memory);
 
 	/// Set the sponsor of the collection.
 	///
@@ -114,6 +107,7 @@
 	///  or in textual repr: setCollectionSponsorSubstrate(uint256)
 	function setCollectionSponsorSubstrate(uint256 sponsor) external;
 
+	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
 	///  or in textual repr: hasCollectionPendingSponsor()
 	function hasCollectionPendingSponsor() external view returns (bool);
@@ -133,9 +127,9 @@
 	/// Get current sponsor.
 	///
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
-	/// @dev EVM selector for this function is: 0xb66bbc14,
-	///  or in textual repr: getCollectionSponsor()
-	function getCollectionSponsor() external view returns (Tuple17 memory);
+	/// @dev EVM selector for this function is: 0x6ec0a9f1,
+	///  or in textual repr: collectionSponsor()
+	function collectionSponsor() external view returns (Tuple17 memory);
 
 	/// Set limits for the collection.
 	/// @dev Throws error if limit not found.
@@ -205,8 +199,7 @@
 	/// @param collections Addresses of collections that will be available for nesting.
 	/// @dev EVM selector for this function is: 0x64872396,
 	///  or in textual repr: setCollectionNesting(bool,address[])
-	function setCollectionNesting(bool enable, address[] memory collections)
-		external;
+	function setCollectionNesting(bool enable, address[] memory collections) external;
 
 	/// Set the collection access method.
 	/// @param mode Access mode
@@ -279,7 +272,7 @@
 	/// @return `Fungible` or `NFT` or `ReFungible`
 	/// @dev EVM selector for this function is: 0xd34b55b8,
 	///  or in textual repr: uniqueCollectionType()
-	function uniqueCollectionType() external returns (string memory);
+	function uniqueCollectionType() external view returns (string memory);
 
 	/// Get collection owner.
 	///
@@ -401,9 +394,7 @@
 	/// @param tokenIds IDs of the minted RFTs
 	/// @dev EVM selector for this function is: 0x44a9945e,
 	///  or in textual repr: mintBulk(address,uint256[])
-	function mintBulk(address to, uint256[] memory tokenIds)
-		external
-		returns (bool);
+	function mintBulk(address to, uint256[] memory tokenIds) external returns (bool);
 
 	/// @notice Function to mint multiple tokens with the given tokenUris.
 	/// @dev `tokenIds` is array of pairs of token ID and token URI. Token IDs should be consecutive
@@ -412,19 +403,14 @@
 	/// @param tokens array of pairs of token ID and token URI for minted tokens
 	/// @dev EVM selector for this function is: 0x36543006,
 	///  or in textual repr: mintBulkWithTokenURI(address,(uint256,string)[])
-	function mintBulkWithTokenURI(address to, Tuple8[] memory tokens)
-		external
-		returns (bool);
+	function mintBulkWithTokenURI(address to, Tuple8[] memory tokens) external returns (bool);
 
 	/// Returns EVM address for refungible token
 	///
 	/// @param token ID of the token
 	/// @dev EVM selector for this function is: 0xab76fac6,
 	///  or in textual repr: tokenContractAddress(uint256)
-	function tokenContractAddress(uint256 token)
-		external
-		view
-		returns (address);
+	function tokenContractAddress(uint256 token) external view returns (address);
 }
 
 /// @dev anonymous struct
@@ -448,10 +434,7 @@
 	/// Not implemented
 	/// @dev EVM selector for this function is: 0x2f745c59,
 	///  or in textual repr: tokenOfOwnerByIndex(address,uint256)
-	function tokenOfOwnerByIndex(address owner, uint256 index)
-		external
-		view
-		returns (uint256);
+	function tokenOfOwnerByIndex(address owner, uint256 index) external view returns (uint256);
 
 	/// @notice Count RFTs tracked by this contract
 	/// @return A count of valid RFTs tracked by this contract, where each one of
@@ -489,21 +472,9 @@
 
 /// @dev inlined interface
 interface ERC721Events {
-	event Transfer(
-		address indexed from,
-		address indexed to,
-		uint256 indexed tokenId
-	);
-	event Approval(
-		address indexed owner,
-		address indexed approved,
-		uint256 indexed tokenId
-	);
-	event ApprovalForAll(
-		address indexed owner,
-		address indexed operator,
-		bool approved
-	);
+	event Transfer(address indexed from, address indexed to, uint256 indexed tokenId);
+	event Approval(address indexed owner, address indexed approved, uint256 indexed tokenId);
+	event ApprovalForAll(address indexed owner, address indexed operator, bool approved);
 }
 
 /// @title ERC-721 Non-Fungible Token Standard
@@ -585,10 +556,7 @@
 	/// @dev Not implemented
 	/// @dev EVM selector for this function is: 0xe985e9c5,
 	///  or in textual repr: isApprovedForAll(address,address)
-	function isApprovedForAll(address owner, address operator)
-		external
-		view
-		returns (address);
+	function isApprovedForAll(address owner, address operator) external view returns (address);
 }
 
 interface UniqueRefungible is
modifiedtests/src/eth/api/UniqueRefungibleToken.soldiffbeforeafterboth